# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class TypeCloudDeployTargetDetailsEnum(object):

    """Implementation of the 'Type_CloudDeployTargetDetails' enum.

    Specifies the type of the CloudDeploy target.
    'kAzure' indicates that Azure as a cloud deploy target type.
    'kAWS' indicates that AWS as a cloud deploy target type.
    'kGCP' indicates that GCP as a cloud deploy target type.

    Attributes:
        KAZURE: TODO: type description here.
        KAWS: TODO: type description here.
        KGCP: TODO: type description here.

    """

    KAZURE = 'kAzure'

    KAWS = 'kAWS'

    KGCP = 'kGCP'

